@@ -9,6 +9,7 @@ from . import tp_link_cipher
 import ast
 import pkgutil
 import uuid
+import json
 
 #Old Functions to get device list from tplinkcloud
 def getToken(email, password):
@@ -67,13 +68,13 @@ class P100():
 		self.keys = RSA.generate(1024)
 
 		self.privateKey = self.keys.exportKey("PEM")
-		self.publicKey  = self.keys.publickey().export_key("PEM")
+		self.publicKey  = self.keys.publickey().exportKey("PEM")
 
 	def decode_handshake_key(self, key):
 		decode: bytes = b64decode(key.encode("UTF-8"))
 		decode2: bytes = self.privateKey
 
-		cipher = PKCS1_v1_5.new(RSA.import_key(decode2))
+		cipher = PKCS1_v1_5.new(RSA.importKey(decode2))
 		do_final = cipher.decrypt(decode, None)
 		if do_final is None:
 			raise ValueError("Decryption failed!")
@@ -282,7 +283,7 @@ class P100():
 		r = requests.post(URL, json=SecurePassthroughPayload, headers=headers)
 		decryptedResponse = self.tpLinkCipher.decrypt(r.json()["result"]["response"])
 
-		return decryptedResponse
+		return json.loads(decryptedResponse)
 
 	def getDeviceName(self):
 		self.handshake()
